Congestion Series
------------------

Aggregated from :ref:`Congestion Vessels`

.. note::
    available on platforms : Platform.Liquids, Platform.LNG, Platform.LPG, Platform.Dry

.. autoclass:: kpler.sdk.resources.congestion_series.CongestionSeries
    :members:

.. autoclass:: kpler.sdk.CongestionSeriesMetric
    :members:

.. autoclass:: kpler.sdk.CongestionSeriesPeriod
    :members:

.. autoclass:: kpler.sdk.CongestionSeriesSplit
    :members:

.. autoclass:: kpler.sdk.CongestionSeriesUnit
    :members:

.. autoclass:: kpler.sdk.VesselTypesCPP
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesOil
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLNG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLPG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesDry
    :members:
    :noindex:

.. autoclass:: kpler.sdk.CongestionSeriesOperation
    :members:
